@@ -5,7 +5,7 @@ import warnings
 
 import PySimpleGUI as sg
 
-__version__ = '1.4.0'
+__version__ = '1.9.0'
 
 """
     PySimpleGUI Demo Program Browser
@@ -469,7 +469,7 @@ def make_window():
 
     right_col = [
         [sg.Multiline(size=(70, 21), write_only=True, key=ML_KEY, reroute_stdout=True, echo_stdout_stderr=True, reroute_cprint=True)],
-        [sg.Button('Edit Me (this program)'), sg.B('Settings'), sg.Button('Exit')],
+        [sg.B('Settings'), sg.Button('Exit')],
         [sg.T('Demo Browser Ver ' + __version__)],
         [sg.T('PySimpleGUI ver ' + sg.version.split(' ')[0] + '  tkinter ver ' + sg.tclversion_detailed, font='Default 8', pad=(0,0))],
         [sg.T('Python ver ' + sys.version, font='Default 8', pad=(0,0))],
